pub enum Error {
ServiceUnavailable,
NoReply,
BadReply,
Post(PostErr),
Remote(RemoteErr),
}Expand description
Mixnet error.
Variants
Failed to communicate with the mixnet service. Possibly it panicked. The node probably needs to be restarted.
NoReply
Did not receive a reply after the configured number of attempts.
BadReply
Received a malformed reply.
Post(PostErr)
Failed to post the request to the mixnet. Note that some PostErr variants, eg
PostErr::NotEnoughSpaceInQueue, are handled internally and will never be returned from
the top-level API.
Remote(RemoteErr)
Error reported by destination mixnode.