pub struct SubstrateConfig {
pub register: bool,
pub num_gateway_slots: u32,
pub request_buffer: usize,
pub surb_factor: usize,
pub extrinsic_queue_capacity: usize,
pub mean_extrinsic_delay: Duration,
pub max_pending_extrinsics: usize,
}Expand description
Substrate-specific mixnet configuration.
Fields
register: boolAttempt to register the local node as a mixnode?
num_gateway_slots: u32Maximum number of incoming mixnet connections to accept from non-mixnodes. If the local node will never be a mixnode, this can be set to 0.
request_buffer: usizeNumber of requests to the mixnet service that can be buffered, in addition to the one per
Api instance. Note that this does not include requests that are being
actively handled.
surb_factor: usizeUsed to determine the number of SURBs to include in request messages: the maximum number of SURBs needed for a single reply is multiplied by this. This should not be set to 0.
extrinsic_queue_capacity: usizeMaximum number of submit extrinsic requests waiting for their delay to elapse. When at the limit, any submit extrinsic requests that arrive will simply be dropped.
mean_extrinsic_delay: DurationMean delay between receiving a submit extrinsic request and actually submitting the extrinsic. This should really be the same for all nodes!
max_pending_extrinsics: usizeMaximum number of extrinsics being actively submitted. If a submit extrinsic request’s delay elapses and we are already at this limit, the request will simply be dropped.