StatementStoreSubscriptionApi

Trait StatementStoreSubscriptionApi 

pub trait StatementStoreSubscriptionApi: Send + Sync {
    // Required method
    fn subscribe_statement(
        &self,
        topic_filter: OptimizedTopicFilter,
    ) -> Result<(Vec<Vec<u8>>, Sender<StatementEvent>, SubscriptionStatementsStream)>;
}
Trait for initiating statement store subscriptions from the RPC module.

Required Methods

fn subscribe_statement( &self, topic_filter: OptimizedTopicFilter, ) -> Result<(Vec<Vec<u8>>, Sender<StatementEvent>, SubscriptionStatementsStream)>

Subscribe to statements matching the topic filter.

Returns existing matching statements, a sender channel to send matched statements and a stream for receiving matched statements when they arrive.

Implementors